List of four different fault-slip data from Angelier (1990):
Usage
data('angelier1990')Details
"AVB" (Agia Varvara, Crete, Greece), "KAM" (Kamogawa, Boso Peninsula, Central Japan),
"MD1" (Arroyo Montado, Baja California, Mexico), and "TYM" (Tymbaki, Crete, Greece).
References
Angelier, J. (1990). Inversion of field data in fault tectonics to obtain the regional stress-III. A new rapid direct inversion method by analytical means. Geophysical Journal International, 103(2), 363–376. doi:10.1111/j.1365-246X.1990.tb01777.x
See also
Other datasets:
example_lines,
example_lines_df,
example_planes,
example_planes_df,
gray_example,
holst,
hossack1968,
osmundsen2010,
ramsay,
shebandowan,
simongomez,
strabo_prj
Examples
data("angelier1990")
head(angelier1990)
#> $AVB
#> Fault object (n = 33):
#> dip_direction dip azimuth plunge sense
#> [1,] 329 71 10.372108 65.35251 1
#> [2,] 315 65 357.248859 57.79119 1
#> [3,] 312 70 1.751099 60.60630 1
#> [4,] 317 63 330.035014 62.39035 1
#> [5,] 134 56 146.384168 55.37193 1
#> [6,] 162 65 141.455533 63.52766 1
#> [7,] 153 70 128.151847 68.14416 1
#> [8,] 316 61 330.212091 60.23864 1
#> [9,] 340 73 356.659170 72.30080 1
#> [10,] 342 72 338.767039 71.97316 1
#> [11,] 323 86 40.883188 71.57529 1
#> [12,] 330 74 21.322413 65.35251 1
#> [13,] 317 77 24.911582 58.45212 1
#> [14,] 325 65 18.796010 51.71010 1
#> [15,] 165 52 124.184821 44.08878 1
#> [16,] 309 85 24.795705 70.37664 1
#> [17,] 312 71 1.697588 61.97195 1
#> [18,] 329 63 6.178380 57.40115 1
#> [19,] 319 58 354.918900 52.34664 1
#> [20,] 317 57 338.319236 55.11920 1
#> [21,] 174 56 136.798420 49.74119 1
#> [22,] 319 40 346.808006 36.58269 1
#> [23,] 159 51 121.223788 44.30632 1
#> [24,] 167 32 140.410590 29.19564 1
#> [25,] 322 54 11.988412 41.50672 1
#> [26,] 149 67 110.958314 61.67654 1
#> [27,] 317 65 9.677250 52.43617 1
#> [28,] 151 86 70.332342 66.67339 1
#> [29,] 317 74 29.406985 46.50824 1
#> [30,] 301 69 11.283948 41.31063 1
#> [31,] 149 65 160.695922 64.53645 1
#> [32,] 146 56 126.832105 54.46945 1
#> [33,] 340 80 334.259926 79.95063 1
#>
#> $KAM
#> Fault object (n = 50):
#> dip_direction dip azimuth plunge sense
#> [1,] 146 66 95.825866 55.1939778 1
#> [2,] 149 67 97.698830 55.8268902 1
#> [3,] 121 55 79.384337 46.8754814 1
#> [4,] 150 52 132.477741 50.6721978 1
#> [5,] 89 36 82.827909 35.8417521 1
#> [6,] 52 70 10.206575 63.9788965 1
#> [7,] 27 55 357.469305 51.1745802 1
#> [8,] 330 67 47.287515 27.4033973 1
#> [9,] 2 60 356.016360 59.8642744 1
#> [10,] 34 64 351.334682 56.4441409 1
#> [11,] 136 39 210.206020 12.4296226 1
#> [12,] 140 40 120.721040 38.3808019 1
#> [13,] 65 55 105.375705 47.4128589 1
#> [14,] 31 73 106.251359 39.7838249 1
#> [15,] 24 70 344.023955 64.5940204 1
#> [16,] 154 20 203.765338 13.2297376 1
#> [17,] 48 35 322.099181 2.8654379 1
#> [18,] 70 40 50.721040 38.3808019 1
#> [19,] 60 43 41.175088 41.4327177 1
#> [20,] 186 50 176.713566 49.6273829 1
#> [21,] 130 40 181.576360 27.5409667 1
#> [22,] 206 29 176.853732 25.8326452 1
#> [23,] 40 35 312.458195 1.7202016 1
#> [24,] 70 40 51.971247 38.5863998 1
#> [25,] 46 2 21.987024 1.8270295 1
#> [26,] 191 20 204.803309 19.4664110 1
#> [27,] 141 52 210.699219 23.9447509 1
#> [28,] 51 85 141.000000 0.0000000 1
#> [29,] 55 78 36.410695 77.3601704 1
#> [30,] 32 77 70.090980 73.6514646 1
#> [31,] 78 76 9.164209 55.3718663 1
#> [32,] 37 77 334.921419 63.7551346 1
#> [33,] 142 23 204.011423 11.2660796 1
#> [34,] 29 46 112.721395 6.4611529 1
#> [35,] 350 77 37.942294 70.9839097 1
#> [36,] 54 17 5.725578 11.5017008 1
#> [37,] 54 17 39.387137 16.4803812 1
#> [38,] 26 49 42.503755 47.8033133 1
#> [39,] 13 68 101.875297 2.7813730 1
#> [40,] 144 44 173.321291 40.0964343 1
#> [41,] 339 50 16.190398 43.5127665 1
#> [42,] 26 60 24.000609 59.9848888 1
#> [43,] 358 57 33.176353 51.5329868 1
#> [44,] 319 46 18.762622 27.5409667 1
#> [45,] 149 51 215.999653 25.7582222 1
#> [46,] 154 60 203.106605 48.5903779 1
#> [47,] 157 42 183.094238 38.9599562 1
#> [48,] 163 45 252.292857 0.7070888 1
#> [49,] 150 43 175.211460 40.1538390 1
#> [50,] 11 85 93.637395 55.6780995 1
#>
#> $MD1
#> Fault object (n = 20):
#> dip_direction dip azimuth plunge sense
#> [1,] 123 64 185.4161 43.51277 1
#> [2,] 293 50 330.1904 43.51277 1
#> [3,] 255 37 294.1162 30.31307 1
#> [4,] 83 50 102.7566 48.28042 1
#> [5,] 240 66 321.5791 18.20700 1
#> [6,] 223 45 284.0814 25.80683 1
#> [7,] 253 55 308.6450 38.86642 1
#> [8,] 200 54 239.6852 46.64713 1
#> [9,] 208 54 271.7470 31.33400 1
#> [10,] 213 52 286.9819 19.45265 1
#> [11,] 240 71 288.1876 62.68496 1
#> [12,] 33 60 103.7047 29.78401 1
#> [13,] 231 69 252.4136 67.59231 1
#> [14,] 255 75 296.7332 70.24885 1
#> [15,] 231 66 295.1391 44.41228 1
#> [16,] 53 66 127.1030 31.60015 1
#> [17,] 73 70 145.8835 38.95996 1
#> [18,] 268 64 314.7687 54.54625 1
#> [19,] 78 58 150.9886 25.08890 1
#> [20,] 235 64 284.2929 53.20956 1
#>
#> $TYM
#> Fault object (n = 38):
#> dip_direction dip azimuth plunge sense
#> [1,] 137 61 117.013494 59.46650 1
#> [2,] 128 59 146.899008 57.58045 1
#> [3,] 2 80 287.530355 56.63295 1
#> [4,] 324 68 294.428870 65.08349 1
#> [5,] 317 63 291.911192 60.63761 1
#> [6,] 22 88 295.324148 58.94196 1
#> [7,] 346 78 280.030566 62.43703 1
#> [8,] 138 60 157.425400 58.52505 1
#> [9,] 349 61 357.207488 60.74920 1
#> [10,] 159 56 155.426604 55.94829 1
#> [11,] 141 70 189.299188 61.31581 1
#> [12,] 308 50 314.208610 49.83395 1
#> [13,] 150 51 167.164526 49.71766 1
#> [14,] 171 62 197.186198 59.35227 1
#> [15,] 328 62 315.380833 61.41529 1
#> [16,] 306 61 277.071031 57.65242 1
#> [17,] 126 60 152.503414 57.17189 1
#> [18,] 129 63 139.907773 62.57518 1
#> [19,] 160 72 101.235974 57.92973 1
#> [20,] 141 53 108.468482 48.20984 1
#> [21,] 281 47 296.908389 45.88274 1
#> [22,] 329 45 298.023689 40.60913 1
#> [23,] 204 74 262.238697 61.42075 1
#> [24,] 297 42 298.345522 41.99214 1
#> [25,] 306 56 311.354144 55.88376 1
#> [26,] 129 77 203.992675 48.28042 1
#> [27,] 149 61 196.641620 50.55577 1
#> [28,] 340 58 8.418328 54.60676 1
#> [29,] 153 67 175.065372 65.39117 1
#> [30,] 120 58 169.700452 45.98728 1
#> [31,] 122 69 108.280689 68.43916 1
#> [32,] 133 63 146.035014 62.39035 1
#> [33,] 115 68 107.035962 67.80646 1
#> [34,] 341 48 348.449152 47.75842 1
#> [35,] 340 69 334.434447 68.90926 1
#> [36,] 287 68 312.206323 65.93702 1
#> [37,] 6 70 322.468751 63.34203 1
#> [38,] 359 71 2.068927 70.97467 1
#>