Decomposition of Orientation Tensor Eigenvectors and Eigenvalues
Usage
ot_eigen(x, scaled = FALSE, ...)
# S3 method for class 'spherical'
ot_eigen(x, scaled = FALSE, ...)
# S3 method for class 'ortensor'
ot_eigen(x, scaled = FALSE, ...)Arguments
- x
either an object of class
"Vec3","Line","Ray","Plane","Pair", or"Fault"where the rows are the observations and the columns are the coordinates, or an"ortensor"object.- scaled
logical. Whether the Eigenvectors should be scaled by the Eigenvalues (only effective if
xis in Cartesian coordinates).- ...
additional arguments passed to
ortensor()(ignored ifxis"ortensor"object).
See also
Other ortensor:
ortensor(),
strain_shape
Examples
set.seed(20250411)
mu <- rvmf(n = 1)
x <- rfb(100, mu = mu, k = 1, A = diag(c(10, 0, 0)))
x_eigen <- ot_eigen(x)
x_eigen
#> eigen() decomposition
#> $values
#> [1] 0.49189600 0.46921551 0.03888849
#>
#> $vectors
#> Vector (Vec3) object (n = 3):
#> x y z
#> [1,] -0.04219599 0.5139000 0.8568117
#> [2,] 0.97090542 0.2234159 -0.0861859
#> [3,] 0.23571626 -0.8282464 0.5083755
#>
plot(x, col = "grey")
points(mu, col = 4)
text(mu, labels = "Mean", col = 4, pos = 4)
points(x_eigen$vectors, col = c(1, 2, 3))
text(x_eigen$vectors, col = c(1, 2, 3), labels = c("E1", "E2", "E3"), pos = 4)