Plot Spherical Objects
Usage
# S3 method for class 'Line'
plot(x, upper.hem = NULL, earea = NULL, grid.params = list(), ...)
# S3 method for class 'Vec3'
plot(x, upper.hem = NULL, earea = NULL, grid.params = list(), ...)
# S3 method for class 'Ray'
plot(x, upper.hem = NULL, earea = NULL, grid.params = list(), pch = NULL, ...)
# S3 method for class 'Plane'
plot(x, upper.hem = NULL, earea = NULL, grid.params = list(), ...)
# S3 method for class 'Pair'
plot(x, upper.hem = NULL, earea = NULL, grid.params = list(), ...)
# S3 method for class 'Fault'
plot(x, upper.hem = NULL, earea = NULL, grid.params = list(), ...)Arguments
- x
object of class
"Vec3","Line","Ray","Plane","Pair", or"Fault", where the rows are the observations and the columns are the coordinates.- upper.hem
logical. Whether the projection is shown for upper hemisphere (
TRUE) or lower hemisphere (FALSE). Defaults togetOption("structr.upper.hem").- earea
logical. Projection, either
TRUEfor Lambert equal-area projection, orFALSEfor meridional stereographic projection. Defaults togetOption("structr.earea").- grid.params
list.
- ...
parameters passed to
stereo_point(),stereo_smallcircle(),stereo_greatcircle(), orfault_plot()- pch
plotting character
Details
If x is a Ray and pch is NULL, solid symbols show rays pointing in the lower hemisphere,
while open symbols point into the upper hemisphere.