Calculate Principal Fault planes from stress vectors and friction
Source:R/stress_inversion.R
principal_fault.RdCalculate Principal Fault planes from stress vectors and friction
See also
stereo_fms() to plot the focal mechanism solution
Examples
s <- reduced_stress(angelier1990$TYM)
stress <- sigma2stress(s)
pr_TYM <- principal_fault(stress$axes[1, ], stress$axes[3, ])
stereoplot()
fault_plot(angelier1990$TYM, col = "grey")
fault_plot(pr_TYM, col = "red")
points(stress$axes, pch = 16)
# Focal mechanism plot
stereoplot()
stereo_fms(s)
fault_plot(angelier1990$TYM, col = "grey30", type = "hoeppener")
points(stress$axes, col = 2:4, pch = 16)