Skip to contents

Simulation of random values from a spherical Kent distribution.

Usage

rkent(n, mu = Vec3(1, 0, 0), k = 5, b)

Arguments

n

integer. number of random samples to be generated

mu

Mean vector. object of class "Vec3", "Line", "Ray", or "Plane", where the rows are the observations and the columns are the coordinates.

k

numeric. The concentration parameter (\(\kappa\)) of the von Mises-Fisher distribution

b

numeric. \(\beta\) (ellipticity): \(0 \leq \beta < \kappa\)

Examples

set.seed(20250411)
r <- rkent(100, mu = Ray(120, 50), k = 5, b = 1)

contour(r)
points(r)