The eigenvector and eigenvalues of a stress tensor give the orientations and relative magnitudes of the principal stress axes.
Value
list with the following components
"sigma_vals"numeric. The relative magnitudes of the principal stress axes.
"sigma_axes"The principal stress axes as
Lineobjects.
See also
Other stress-tensor:
fault_instability_criterion(),
reduced_stress(),
sigma-comp,
sigma2rup(),
stress_shape()
Examples
f <- angelier1990$TYM
s <- reduced_stress(f)
sigma2stress(s)
#> $vals
#> sigma1 sigma2 sigma3
#> 1.5186760 -0.6378677 -0.8808083
#>
#> $axes
#> Line object (n = 3):
#> azimuth plunge
#> sigma1 225.71104 84.219427
#> sigma2 62.26628 5.542466
#> sigma3 332.10740 1.636857
#>