Skip to contents

Adds an ellipse marking the bootstrapped confidence interval of the arithmetic mean to an existing plot

Usage

stereo_confidence(
  x,
  params = list(),
  .center = TRUE,
  col = par("col"),
  cex = par("cex"),
  pch = 16,
  upper.hem = NULL,
  earea = NULL,
  radius = NULL,
  ...
)

Arguments

x

Spherical object or a list containing the output of an earlier call of confidence_ellipse()

params

list. Parameters passed to confidence_ellipse()

.center

logical. Whether the ellipse's center should be plotted?

col

Color of the ellipse and its center

pch, cex

Plotting symbol and size of the ellipse center. Ignored if .center is FALSE.

upper.hem

logical. Whether the projection is shown for upper hemisphere (TRUE) or lower hemisphere (FALSE). Defaults to getOption("structr.upper.hem").

earea

logical. Projection, either TRUE for Lambert equal-area projection, or FALSE for meridional stereographic projection. Defaults to getOption("structr.earea").

radius

numeric. Radius of circle. Defaults to getOption("structr.radius").

...

graphical parameters passed to graphics::lines()

Value

output of confidence_ellipse()

Examples

set.seed(20250411)
plot(example_lines, col = "grey")
stereo_confidence(example_lines, params = list(n = 100, res = 100), col = "red")