Skip to contents

Draws simple lines between vector points in stereographic or equal-area projection

Usage

stereo_lines(x, upper.hem = NULL, earea = NULL, radius = NULL, ...)

Arguments

x

object of class "Vec3", "Line", "Ray", "Plane", "Pair", or "Fault", where the rows are the observations and the columns are the coordinates.

upper.hem

logical. Whether the projection is shown for upper hemisphere (TRUE) or lower hemisphere (FALSE). Defaults to getOption("structr.upper.hem").

earea

logical. Projection, either TRUE for Lambert equal-area projection, or FALSE for meridional stereographic projection. Defaults to getOption("structr.earea").

radius

numeric. Radius of circle. Defaults to getOption("structr.radius").

...

optional graphical parameters passed to graphics::lines()

Value

two-column matrix of the stereographic or equal-area coordinates

Examples

plot(example_lines, col = "grey")
stereo_lines(example_lines[1:2, ], col = "red")