Skip to contents

Visualization of lines, planes in a stereographic projection.

Usage

stereo_point(
  x,
  col = 1,
  pch = 20,
  lab = NULL,
  text.pos = 4,
  cex = 1,
  upper.hem = NULL,
  earea = NULL,
  ...
)

Arguments

x

object of class "Vec3", "Line", "Ray", "Plane", "Pair", or "Fault", where the rows are the observations and the columns are the coordinates.

col

color

pch

plotting character

lab

character. text labels

text.pos

position for labels

cex

character expansion of labels

upper.hem

logical. Whether the projection is shown for upper hemisphere (TRUE) or lower hemisphere (FALSE). Defaults to getOption("structr.upper.hem").

earea

logical. Projection, either TRUE for Lambert equal-area projection, or FALSE for meridional stereographic projection. Defaults to getOption("structr.earea").

...

optional graphical parameters

Value

two-column matrix of the stereographic or equal-area coordinates

Note

"Plane" and "Fault" objects will be displayed as pole to the plane (only).

Examples

stereoplot()
stereo_point(Line(c(90, 80), c(10, 75)), lab = c("L1", "L2"))
stereo_point(Plane(120, 30), lab = "P", col = "red")