Skip to contents

Adds equal-area or equal-angle projection grid to an existing stereoplot

Usage

stereoplot_guides(
  d = 10,
  earea = NULL,
  radius = NULL,
  center = NULL,
  equator = TRUE,
  lwd = 0.5,
  equator_lwd = lwd * 1.5,
  ...
)

Arguments

d

angle spacing between grid lines of the projection

earea

logical. Projection, either TRUE for Lambert equal-area projection, or FALSE for meridional stereographic projection. Defaults to getOption("structr.earea").

radius

numeric. Radius of circle. Defaults to getOption("structr.radius").

center

Center position of grid lines. If NULL (the default), grid lines are centered on the origin of the stereoplot. Otherwise, this should be a spherical object.

equator

logical. Whether the grid equator should be shown no matter how the grid is constructed via d. TRUE by default.

lwd

Width of guide lines. Defaults to getOption("structr.lwd").

equator_lwd

numeric. The line width of the drawn equator grid line. By default, the equator is 1.5 times thicker then lwd.

...

optional arguments passed to graphics::lines()

Examples

plot(c(-1, 1), c(-1, 1), type = "n", asp = 1)
stereoplot_guides(d = 5, earea = FALSE, col = "green", rotation = 20)


plot(c(-1, 1), c(-1, 1), type = "n", asp = 1)
stereoplot_guides(d = 15, earea = TRUE, col = "orange", rotation = 90)


plot(c(-1, 1), c(-1, 1), type = "n", asp = 1)
stereoplot_guides(d = 15, earea = FALSE, center = Line(120, 50), col = 'red')