Skip to contents

The eigenvector and eigenvalues of a stress tensor give the orientations and relative magnitudes of the principal stress axes.

Usage

tau2stress(tau)

Arguments

tau

symmetric 3x3 matrix. The (reduced) stress tensor.

Value

list with the following components

"sigma_vals"

numeric. The relative magnitudes of the principal stress axes.

"principal_axes"

The principal stress axes as Line objects.

Examples

f <- angelier1990$TYM
tau <- reduced_stress(f)
tau2stress(tau)
#> $sigma_vals
#>     sigma1     sigma2     sigma3 
#>  1.5186760 -0.6378677 -0.8808083 
#> 
#> $principal_axes
#> Line object (n = 3):
#>          azimuth    plunge
#> sigma1 225.71104 84.219427
#> sigma2  62.26628  5.542466
#> sigma3 332.10740  1.636857
#>