Skip to contents

Add Points to a Plot

Usage

# S3 method for class 'spherical'
text(x, labels = seq_along(x[, 1]), upper.hem = NULL, earea = NULL, ...)

Arguments

x

object of class "Vec3", "Line", "Ray", "Plane", "Pair", or "Fault", where the rows are the observations and the columns are the coordinates.

labels

a character vector or expression specifying the text to be written. An attempt is made to coerce other language objects (names and calls) to expressions, and vectors and other classed objects to character vectors by as.character. If labels is longer than x and y, the coordinates are recycled to the length of labels.

upper.hem

logical. Whether the projection is shown for upper hemisphere (TRUE) or lower hemisphere (FALSE). Defaults to getOption("structr.upper.hem").

earea

logical. Projection, either TRUE for Lambert equal-area projection, or FALSE for meridional stereographic projection. Defaults to getOption("structr.earea").

...

arguments passed to graphics::text()

Examples

stereoplot()
points(Line(c(90, 80), c(10, 75)), col = 1:2)
text(Line(c(90, 80), c(10, 75)), labels = c("L1", "L2"), col = 1:2, pos = 3)