Calculate Principal Fault planes from stress vectors and friction
Source:R/stress_inversion.R
principal_fault.RdCalculate Principal Fault planes from stress vectors and friction
Examples
s <- reduced_stress(angelier1990$TYM)
stress <- sigma2stress(s)
pr_TYM <- principal_fault(stress$axes[1, ], stress$axes[3, ])
stereoplot()
fault_plot(angelier1990$TYM, col = "grey")
fault_plot(pr_TYM, col = "red")
points(stress$axes, pch = 16)