Simulation of random values from a spherical Kent distribution.
Usage
rkent(n, mu = Vec3(1, 0, 0), k = 5, b)Arguments
- n
integer. number of random samples to be generated
- mu
Mean vector. object of class
"Vec3","Line","Ray", or"Plane", where the rows are the observations and the columns are the coordinates.- k
numeric. The concentration parameter (\(\kappa\)) of the von Mises-Fisher distribution
- b
numeric. \(\beta\) (ellipticity): \(0 \leq \beta < \kappa\)
See also
Other random:
rbing,
rfb(),
rrot(),
runif.spherical(),
rwatson(),
vonmises-fisher