Skip to contents

Visualization of smallcircles and greatcircles in a stereographic projection.

Usage

stereo_smallcircle(
  x,
  d = 90,
  col = 1,
  N = 1000,
  upper.hem = NULL,
  earea = NULL,
  lty = 1,
  lwd = 1,
  radius = NULL,
  ...
)

stereo_greatcircle(x, ...)

Arguments

x

object of class "Vec3", "Line", "Ray", "Plane", "Pair", or "Fault", where the rows are the observations and the columns are the coordinates.

d

numeric. conical angle in degrees.

col, lty, lwd

color, line type, and line width parameters

N

integer. number of points to calculate

upper.hem

logical. Whether the projection is shown for upper hemisphere (TRUE) or lower hemisphere (FALSE). Defaults to getOption("structr.upper.hem").

earea

logical. Projection, either TRUE for Lambert equal-area projection, or FALSE for meridional stereographic projection. Defaults to getOption("structr.earea").

radius

numeric. Radius of circle. Defaults to getOption("structr.radius").

...

optional graphical parameters passed to graphics::lines()

Examples

stereoplot()
stereo_point(Line(90, 5), lab = "L")
stereo_smallcircle(Line(90, 5), d = 10)
stereo_point(Plane(120, 30), lab = "P", col = "red")
stereo_greatcircle(Plane(120, 30), col = "red")


stereoplot()
stereo_point(Line(c(129, 90), c(30, 5)), lab = c("L1", "L2"))
stereo_smallcircle(Line(c(129, 90), c(30, 5)), d = c(10, 5), col = 1:2, lty = 1:2, lwd = 1:2)