Draws simple lines between vector points in stereographic or equal-area projection
Arguments
- x
object of class
"Vec3","Line","Ray","Plane","Pair", or"Fault", where the rows are the observations and the columns are the coordinates.- upper.hem
logical. Whether the projection is shown for upper hemisphere (
TRUE) or lower hemisphere (FALSE). Defaults togetOption("structr.upper.hem").- earea
logical. Projection, either
TRUEfor Lambert equal-area projection, orFALSEfor meridional stereographic projection. Defaults togetOption("structr.earea").- radius
numeric. Radius of circle. Defaults to
getOption("structr.radius").- ...
optional graphical parameters passed to
graphics::lines()
See also
slerp(), stereo_greatcircle, stereo_lines(), stereo_segment()
Other stereo-plot:
arrows(),
fault-plot,
lines(),
plot-spherical,
points.spherical(),
stereo_cones,
stereo_confidence(),
stereo_contour,
stereo_point(),
stereo_segment(),
stereoplot(),
stereoplot_guides(),
stereoplot_ticks(),
text.spherical()
Examples
plot(example_lines, col = "grey")
stereo_lines(example_lines[1:2, ], col = "red")