Add Points to a Plot
Arguments
- x
object of class
"Vec3","Line","Ray","Plane","Pair", or"Fault", where the rows are the observations and the columns are the coordinates.- labels
a character vector or expression specifying the text to be written. An attempt is made to coerce other language objects (names and calls) to expressions, and vectors and other classed objects to character vectors by
as.character. Iflabelsis longer thanxandy, the coordinates are recycled to the length oflabels.- upper.hem
logical. Whether the projection is shown for upper hemisphere (
TRUE) or lower hemisphere (FALSE). Defaults togetOption("structr.upper.hem").- earea
logical. Projection, either
TRUEfor Lambert equal-area projection, orFALSEfor meridional stereographic projection. Defaults togetOption("structr.earea").- ...
arguments passed to
graphics::text()