Density and random generation for the spherical normal distribution with mean and concentration parameter (\(\kappa\)) .
Adapted fom rotasym::r_vMF() and rotasym::d_vMF(), and
geologyGeometry by Davis, J.R.
Arguments
- n
integer. number of random samples to be generated
- mu
Mean vector. object of class
"Vec3","Line","Ray", or"Plane", where the rows are the observations and the columns are the coordinates.- k
numeric. The concentration parameter (\(\kappa\)) of the von Mises-Fisher distribution
- method
character. Algorithm to generate random vectors from a Fisher distribution. Either
"geologyGeometry"(the default) to pick therayFisher()algorithm from the geologyGeometry code compilation, or"rotasym"to pick therotasym::r_vMF()algorithm from the rotasym package.- x
object of class
"Vec3","Line","Ray", or"Plane", where the rows are the observations and the columns are the coordinates.